<h2>[% IF data.reviewtypeid %]Edit[% ELSE %]Add[% END %] Link</h2>

    <p>
      <a href="[% cgipath %]/pages.cgi?act=reviews-admin">manage reviews</a>
    | <a href="[% cgipath %]/pages.cgi?act=reviews-typesadmin">manage review types</a>
    | <a href="[% cgipath %]/pages.cgi?act=reviews-radmin">manage retailers</a>
    </p>

<form method="post" action="[% cgipath %]/pages.cgi">
<input type="hidden" name="act" value="reviews-typessave" />
<input type="hidden" name="reviewtypeid" value="[% data.reviewtypeid %]" />

<div class="boxer">
<div class="blocker">
[% IF thanks %]<p>Review type saved successfully.[% END %]
[% IF errmess %]
[% IF errmess == 1 %]
<p class="alert">There are invalid or missing fields, as noted by the <span class="red">&empty;</span> symbol.
[% ELSE %]
<p class="alert">[% errmess %]
[% END %]
[% END %]
</div>
</div>

<div class="boxer">
<table class="blocker">
<tr><th>Name *</th>
    <td class="red">[% data.typename_err %]</td>
    <td><input type="text" name="typename" id="typename" size="55" value="[% data.typename %]" /></td></tr>
<tr><th>Abbrieviation *</th>
    <td class="red">[% date.typeabbr_err %]</td>
    <td><input type="text" name="typeabbr" id="typeabbr" size="55" value="[% data.typeabbr %]" /></td></tr>
</table>
</div>

<p align="center"><input type="submit" value="Save Review Type" />

</form>
